@@ -114,7 +114,7 @@ class Respuesta(BaseModel):
         mensaje = etree.Element('mensaje', categoria=self.categoria)
         orden_pago = etree.SubElement(mensaje, 'respuesta')
 
-        for element, value in self.dict().items():  # noqa: WPS110
+        for element, value in self.dict(exclude={'categoria',}).items():  # noqa: WPS110
             if element in self.__fields__:
                 upper_camel_case_element = to_upper_camel_case(element)
                 subelement = etree.SubElement(orden_pago, upper_camel_case_element)
